@@ -7,10 +7,10 @@ import torch
 from torch.nn import Module
 from torchvision.ops import roi_pool as _roi_pool
 from torchvision.ops import roi_align as _roi_align
-from leanai.model.module_registry import add_module
+from leanai.model.module_registry import register_module
 
 
-@add_module()
+@register_module()
 class BoxToRoi(Module):
     def __init__(self, feature_map_scale=1) -> None:
         super().__init__()
@@ -24,7 +24,7 @@ class BoxToRoi(Module):
         return corners / self.feature_map_scale
 
 
-@add_module()
+@register_module()
 class RoiPool(Module):
     def __init__(self, output_size, spatial_scale=1.0):
         """
@@ -54,7 +54,7 @@ class RoiPool(Module):
         return result.view(-1, C * self.output_size[0]* self.output_size[1])
 
 
-@add_module()
+@register_module()
 class RoiAlign(Module):
     def __init__(self, output_size, spatial_scale=1.0):
         """
